@@ -7,7 +7,7 @@ from sqlalchemy.orm import sessionmaker
 SQLALCHEMY_BINDS = {
     'cargoline':'mysql://root:RHyndmanfpp3@127.0.0.1:3306/cargoline',
     'usermanagement': 'mysql://root:RHyndmanfpp3@localhost/cargocast_usermanagement',
-    'forecast': 'mysql://root:RHyndmanfpp3@localhost/cargocast_forecast',
+    'forecast': 'mysql://root:RHyndmanfpp3@localhost/consignment',
     'company':  'mysql://root:RHyndmanfpp3@localhost/company'
 }
 
@@ -22,7 +22,5 @@ meta = MetaData()
 Base = declarative_base(metadata = meta)
 
 
-# Cargoline_Base = declarative_base(bind = cargoline_engine,metadata = meta)
-# Usermanagement_Base = declarative_base(bind = usermanagement_engine,metadata = meta)
-# Forecast_Base = declarative_base(bind = forecast_engine,metadata = meta)
-# Company_Base = declarative_base(bind = company_engine,metadata = meta)
+# C:/Users/p.dietrich/Documents/CargoCast/cc_db
+
